@@ -211,7 +211,7 @@ namespace MonoDevelop.ValaBinding
 		/// <summary>
 		/// Ths pkg-config package is for internal MonoDevelop use only, it is not deployed.
 		/// </summary>
-		public void WriteMDPkgPackage (string configuration)
+		public void WriteMDPkgPackage (ConfigurationSelector configuration)
 		{
 			string pkgfile = Path.Combine (BaseDirectory, Name + ".md.pc");
 			
@@ -242,7 +242,7 @@ namespace MonoDevelop.ValaBinding
 		/// This is the pkg-config package that gets deployed.
 		/// <returns>The pkg-config package's filename</returns>
 		/// </summary>
-		private string WriteDeployablePkgPackage (string configuration)
+		private string WriteDeployablePkgPackage (ConfigurationSelector configuration)
 		{
 			// FIXME: This should probably be grabed from somewhere.
 			string prefix = "/usr/local";
@@ -270,7 +270,7 @@ namespace MonoDevelop.ValaBinding
 			return pkgfile;
 		}
 		
-		protected override BuildResult DoBuild (IProgressMonitor monitor, string configuration)
+		protected override BuildResult DoBuild (IProgressMonitor monitor, ConfigurationSelector configuration)
 		{
 			ValaProjectConfiguration pc = (ValaProjectConfiguration)GetConfiguration(configuration);
 			pc.SourceDirectory = BaseDirectory;
@@ -280,23 +280,29 @@ namespace MonoDevelop.ValaBinding
 				pc,
 				monitor);
 		}
+		
+		ExecutionCommand CreateExecutionCommand (ValaProjectConfiguration conf)
+		{
+			NativeExecutionCommand cmd = new NativeExecutionCommand ();
+			cmd.Command = Path.Combine (conf.OutputDirectory, conf.Output);
+			cmd.Arguments = conf.CommandLineParameters;
+			cmd.WorkingDirectory = Path.GetFullPath (conf.OutputDirectory);
+			return cmd;
+		}
 
-		protected override bool OnGetCanExecute (MonoDevelop.Projects.ExecutionContext context, string solutionConfiguration)
+		protected override bool OnGetCanExecute (MonoDevelop.Projects.ExecutionContext context, ConfigurationSelector solutionConfiguration)
 		{
 			ValaProjectConfiguration conf = (ValaProjectConfiguration)GetConfiguration(solutionConfiguration);
+			ExecutionCommand cmd = CreateExecutionCommand (conf);
 			return (conf.CompileTarget == ValaBinding.CompileTarget.Bin) &&
-				context.ExecutionHandler.CanExecute (Path.Combine (conf.OutputDirectory, conf.Output));
+				context.ExecutionHandler.CanExecute (cmd);
 		}
 		
 		protected override void DoExecute (IProgressMonitor monitor,
 										   ExecutionContext context,
-		                                   string configuration)
+		                                   ConfigurationSelector configuration)
 		{
-			ValaProjectConfiguration conf = (ValaProjectConfiguration)GetConfiguration(configuration);
-			string command = conf.Output;
-			string args = conf.CommandLineParameters;
-			string dir = Path.GetFullPath (conf.OutputDirectory);
-			string platform = "Native";
+			ValaProjectConfiguration conf = (ValaProjectConfiguration) GetConfiguration (configuration);
 			bool pause = conf.PauseConsoleOutput;
 			IConsole console;
 			
@@ -305,6 +311,8 @@ namespace MonoDevelop.ValaBinding
 				return;
 			}
 			
+			ExecutionCommand cmd = CreateExecutionCommand (conf);
+			
 			monitor.Log.WriteLine ("Running project...");
 			
 			if (conf.ExternalConsole)
@@ -315,29 +323,29 @@ namespace MonoDevelop.ValaBinding
 			AggregatedOperationMonitor operationMonitor = new AggregatedOperationMonitor (monitor);
 			
 			try {
-				if (!context.ExecutionHandler.CanExecute (Path.Combine (dir, command))) {
-					monitor.ReportError ("Cannot execute \"" + command + "\". The selected execution mode is not supported for Vala projects.", null);
+				if (!context.ExecutionHandler.CanExecute (cmd)) {
+					monitor.ReportError ("Cannot execute \"" + conf.Output + "\". The selected execution mode is not supported for Vala projects.", null);
 					return;
 				}
 				
-				IProcessAsyncOperation op = context.ExecutionHandler.Execute (Path.Combine (dir, command), args, dir, null, console);
+				IProcessAsyncOperation op = context.ExecutionHandler.Execute (cmd, console);
 				
 				operationMonitor.AddOperation (op);
 				op.WaitForCompleted ();
 				
 				monitor.Log.WriteLine ("The operation exited with code: {0}", op.ExitCode);
 			} catch (Exception ex) {
-				monitor.ReportError ("Cannot execute \"" + command + "\"", ex);
+				monitor.ReportError ("Cannot execute \"" + conf.Output + "\"", ex);
 			} finally {			
 				operationMonitor.Dispose ();			
 				console.Dispose ();
 			}
 		}
 		
-		protected override string OnGetOutputFileName (string configuration)
+		public override FilePath GetOutputFileName (ConfigurationSelector configuration)
 		{
 			ValaProjectConfiguration conf = (ValaProjectConfiguration)GetConfiguration(configuration);
-			return Path.Combine (conf.OutputDirectory, conf.CompiledOutputName);
+			return conf.OutputDirectory.Combine (conf.CompiledOutputName);
 		}
 		
 		public override SolutionItemConfiguration CreateConfiguration (string name)
@@ -375,8 +383,9 @@ namespace MonoDevelop.ValaBinding
 			set {
 				packages = value;
 				packages.Project = this;
+				ProjectInformation pi = ProjectInformationManager.Instance.Get (this);
 				foreach(ProjectPackage p in packages) {
-					TagDatabaseManager.Instance.UpdateFileTags(this, p.File);
+					if (!p.IsProject){ pi.AddPackage (p.Name); }
 				}
 			}
 		}
@@ -391,21 +400,20 @@ namespace MonoDevelop.ValaBinding
 			}
 			
 			if (e.ProjectFile.BuildAction == BuildAction.Compile)
-				TagDatabaseManager.Instance.UpdateFileTags (this, e.ProjectFile.Name);
+				ProjectInformationManager.Instance.Get (this).AddFile (e.ProjectFile.FilePath);
 		}
 		
 		protected override void OnFileChangedInProject (ProjectFileEventArgs e)
 		{
 			base.OnFileChangedInProject (e);
-			
-			TagDatabaseManager.Instance.UpdateFileTags (this, e.ProjectFile.Name);
+//			ProjectInformationManager.Instance.Get (this).Reparse ();
+			ProjectInformationManager.Instance.Get (this).AddFile (e.ProjectFile.FilePath);
 		}
 		
 		protected override void OnFileRemovedFromProject (ProjectFileEventArgs e)
 		{
 			base.OnFileRemovedFromProject(e);
-			
-			TagDatabaseManager.Instance.RemoveFileInfo (this, e.ProjectFile.Name);
+			ProjectInformationManager.Instance.Get (this).RemoveFile (e.ProjectFile.FilePath);
 		}
 		
 		private static void OnEntryAddedToCombine (object sender, SolutionItemEventArgs e)
@@ -415,10 +423,10 @@ namespace MonoDevelop.ValaBinding
 			if (p == null)
 				return;
 			
-			foreach (ProjectFile f in p.Files)
-				TagDatabaseManager.Instance.UpdateFileTags (p, f.Name);
 			foreach (ProjectPackage package in p.Packages)
-				TagDatabaseManager.Instance.UpdateFileTags (p, package.File);
+				if (!package.IsProject){ ProjectInformationManager.Instance.Get (p).AddPackage (package.Name); }
+			foreach (ProjectFile f in p.Files)
+				ProjectInformationManager.Instance.Get (p).AddFile (f.FilePath);
 		}
 		
 		internal void NotifyPackageRemovedFromProject (ProjectPackage package)
@@ -426,7 +434,6 @@ namespace MonoDevelop.ValaBinding
 			if (null != PackageRemovedFromProject) {
 				PackageRemovedFromProject (this, new ProjectPackageEventArgs (this, package));
 			}
-			TagDatabaseManager.Instance.RemoveFileInfo(this, package.File);
 		}
 		
 		internal void NotifyPackageAddedToProject (ProjectPackage package)
@@ -434,10 +441,10 @@ namespace MonoDevelop.ValaBinding
 			if(null != PackageAddedToProject) {
 				PackageAddedToProject (this, new ProjectPackageEventArgs (this, package));
 			}
-			TagDatabaseManager.Instance.UpdateFileTags(this, package.File);
+			if (!package.IsProject){ ProjectInformationManager.Instance.Get (this).AddPackage (package.Name); }
 		}
 
-		public DeployFileCollection GetDeployFiles (string configuration)
+		public DeployFileCollection GetDeployFiles (ConfigurationSelector configuration)
 		{
 			DeployFileCollection deployFiles = new DeployFileCollection ();
 			
@@ -492,20 +499,22 @@ namespace MonoDevelop.ValaBinding
 
 			string depsfile = Path.ChangeExtension (package.File, ".deps");
 			try {
-				string[] lines = File.ReadAllLines (depsfile);
-				List<ProjectPackage> deps = new List<ProjectPackage>();
-				foreach (string line in lines) {
-					deps.Add(new ProjectPackage(Path.Combine(vapidir, line) + ".vapi"));
-				}// add package for each dep
-				packages.AddRange(deps);
+				if (File.Exists (depsfile)) {
+					string[] lines = File.ReadAllLines (depsfile);
+					List<ProjectPackage> deps = new List<ProjectPackage>();
+					foreach (string line in lines) {
+						deps.Add(new ProjectPackage(Path.Combine(vapidir, line) + ".vapi"));
+					}// add package for each dep
+					packages.AddRange(deps);
+				}
 
 				// Currently, we need to add include directory and linker flags - this should be obsoleted
 				string ccargs = string.Format (" --Xcc=\\\\\\\"-I{0}\\\\\\\" --Xcc=\\\\\\\"-L{0}\\\\\\\" --Xcc=\\\\\\\"-l{1}\\\\\\\" ", Path.GetDirectoryName (depsfile), package.Name);
 				string ldpath = string.Empty;
 				string packagePath = Path.GetDirectoryName(package.File);
 				
-				foreach (string pc in GetConfigurations ()) {
-					ValaProjectConfiguration valapc = GetConfiguration (pc) as ValaProjectConfiguration;
+				foreach (ItemConfiguration pc in Configurations) {
+					ValaProjectConfiguration valapc = pc as ValaProjectConfiguration;
 					if (null == valapc){ continue; }
 
 					ValaCompilationParameters vcp = (ValaCompilationParameters)valapc.CompilationParameters;
